@@ -1527,8 +1527,9 @@ class NonCOP(Experiment):
         Experiment.__init__(self,idir,ndir,**keyargs)
 
         # initialize Ang2Q conversion
-        self._A2QConversion = QConversion(['x+','y+','z-'],'x+',[0,1,0],wl=self._wl) # 3S+1D goniometer (as in the MRD, omega,chi,phi,theta)
-        self.Ang2Q = self._A2QConversion
+        if "qconv" not in keyargs:
+            self._A2QConversion = QConversion(['x+','y+','z-'],'x+',[0,1,0],wl=self._wl) # 3S+1D goniometer (standard four-circle goniometer, omega,chi,phi,theta)
+            self.Ang2Q = self._A2QConversion
 
     def Ang2Q(self,om,chi,phi,tt,**kwargs):
         """
@@ -1687,8 +1688,9 @@ class GID(Experiment):
         Experiment.__init__(self,idir,ndir,**keyargs)
 
         # initialize Ang2Q conversion
-        self._A2QConversion = QConversion(['z-','x+'],['x+','z-'],[0,1,0],wl=self._wl) # 2S+2D goniometer
-        self.Ang2Q = self._A2QConversion
+        if "qconv" not in keyargs:
+            self._A2QConversion = QConversion(['z-','x+'],['x+','z-'],[0,1,0],wl=self._wl) # 2S+2D goniometer
+            self.Ang2Q = self._A2QConversion
 
     def _set_transform(self,v1,v2,v3):
         """
@@ -1807,102 +1809,6 @@ class GID(Experiment):
         # the real function is generated dynamically in the __init__ routine
         pass
 
-class GID_ID10B(GID):
-    """
-    class describing grazing incidence x-ray diffraction experiments
-    the class helps with calculating the angles of Bragg reflections
-    as well as it helps with analyzing measured data
-
-    the class describes a four circle (theta,omega,delta,gamma)
-    goniometer to help with GID experiments at ID10B / ESRF.
-    3D data can be treated with the use of linear and area detectors.
-    see help self.Ang2Q
-    """
-    def __init__(self,idir,ndir,**keyargs):
-        """
-        initialization routine for the GID Experiment class
-
-        idir defines the inplane reference direction (idir points into the PB
-        direction at zero angles)
-
-        Parameters
-        ----------
-        same as for the Experiment base class
-
-        """
-        Experiment.__init__(self,idir,ndir,**keyargs)
-
-        # initialize Ang2Q conversion
-        self._A2QConversion = QConversion(['x+','z-'],['x+','z-'],[0,1,0],wl=self._wl) # 2S+2D goniometer
-        self.Ang2Q = self._A2QConversion
-
-    def Ang2Q(self,th,om,delta,gamma,**kwargs):
-        """
-        angular to momentum space conversion for a point detector. Also see
-        help GID_ID10B.Ang2Q for procedures which treat line and area detectors
-
-        Parameters
-        ----------
-         th,om,delta,gamma: sample and detector angles as numpy array, lists or Scalars
-                        must be given. all arguments must have the same shape or
-                        length
-
-        **kwargs:   optional keyword arguments
-            delta:  giving delta angles to correct the given ones for misalignment
-                    delta must be an numpy array or list of length 4.
-                    used angles are than th,om,delta,gamma - delta
-            UB:     matrix for conversion from (hkl) coordinates to Q of sample
-                    used to determine not Q but (hkl)
-                    (default: identity matrix)
-            wl:     x-ray wavelength in angstroem (default: self._wl)
-            deg:    flag to tell if angles are passed as degree (default: True)
-
-        Returns
-        -------
-        reciprocal space positions as numpy.ndarray with shape ( * , 3 )
-        where * corresponds to the number of points given in the input
-        """
-        # dummy function to have some documentation string available
-        # the real function is generated dynamically in the __init__ routine
-        pass
-
-    def Q2Ang(self,Q,trans=True,deg=True,**kwargs):
-        """
-        calculate the GID angles needed in the experiment
-        the inplane reference direction defines the direction were
-        the reference direction is parallel to the primary beam
-        (i.e. lattice planes perpendicular to the beam)
-
-        Parameters
-        ----------
-         Q:          a list or numpy array of shape (3) with
-                     q-space vector components
-
-        optional keyword arguments:
-         trans:      True/False apply coordinate transformation on Q
-         deg:        True/Flase (default True) determines if the
-                     angles are returned in radians or degrees
-
-        Returns
-        -------
-        a numpy array of shape (4) with the four GID scattering angles which are
-        (theta,omega,delta,gamma)
-
-         theta:    incidence angle to surface (at the moment always 0)
-         omega:    sample rotation with respect to the inplane reference direction
-         delta:    exit angle from surface (at the moment always 0)
-         gamma:    scattering angle
-        """
-
-        for k in kwargs.keys():
-            if k not in ['trans','deg']:
-                raise Exception("unknown keyword argument given: allowed are 'trans': coordinate transformation flag, 'deg': degree-flag")
-        
-        [ai,azi,tt,beta] = GID.Q2Ang(self, Q, trans,deg, **kwargs)
-
-        return [0,azi,0,tt]
-
-
 class GISAXS(Experiment):
     """
     class describing grazing incidence x-ray diffraction experiments
