@@ -14,7 +14,7 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 # Copyright (C) 2009-2010 Eugen Wintersberger <eugen.wintersberger@desy.de>
-# Copyright (C) 2009-2012 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (C) 2009-2013 Dominik Kriegner <dominik.kriegner@gmail.com>
 
 """
 a threaded class for observing a SPEC data file
@@ -32,6 +32,7 @@ import numpy
 import os
 import time
 import tables
+import gzip
 
 # relative imports from xrayutilities
 from .. import config
@@ -551,7 +552,10 @@ class SPECFile(object):
         self.scan_list = []
         #open the file for reading
         try:
-            self.fid = open(self.full_filename,"rb")
+            if os.path.splitext(self.full_filename)[-1] == '.gz':
+                self.fid = gzip.open(self.full_filename,"rb")
+            else :
+                self.fid = open(self.full_filename,"rb")
             self.last_offset = self.fid.tell()
         except:
             self.fid = None
@@ -628,7 +632,10 @@ class SPECFile(object):
 
         self.fid.close()
         try:
-            self.fid = open(self.full_filename,"r")
+            if os.path.splitext(self.full_filename)[-1] == '.gz':
+                self.fid = gzip.open(self.full_filename,"rb")
+            else :
+                self.fid = open(self.full_filename,"rb")
         except:
             self.fid = None
             raise IOError("error opening SPEC file %s" %(self.full_filename))
@@ -872,7 +879,10 @@ class SPECLog(object):
         self.full_filename = os.path.join(path,self.filename)
 
         try:
-            self.fid = open(self.full_filename,"r")
+            if os.path.splitext(self.full_filename)[-1] == '.gz':
+                self.fid = gzip.open(self.full_filename,"r")
+            else :
+                self.fid = open(self.full_filename,"r")
         except:
             raise IOError("cannot open log file %s" %(self.full_filename))
 
