@@ -808,3 +808,71 @@ def GeTeRhombohedral(aa,ab,a,ang,x=0.237):
     l = Lattice(a1,a2,a3,base=lb)
 
     return l    
+
+def MagnetiteLattice( aa , ab , ac , a ,x = 0.255):
+    lb = LatticeBase()
+    #Fe1
+    lb.append(aa,[0.125,0.125,0.125])
+    lb.append(aa,[0.875,0.375,0.375])
+    lb.append(aa,[0.375,.875,.375])
+    lb.append(aa,[0.375,0.375,.875])
+    lb.append(aa,[.875,.875,.875])
+    lb.append(aa,[.125,.625,.625])
+    lb.append(aa,[.625,.125,.625])
+    lb.append(aa,[.625,.625,.125])
+    #Fe2
+    lb.append(ab,[0.5,0.5,0.5])
+    lb.append(ab,[.5,0.75,0.75])
+    lb.append(ab,[0.75,0.75,0.5])
+    lb.append(ab,[0.75,0.5,0.75])
+    lb.append(ab,[0.5,0.25,.25])
+    lb.append(ab,[.25,.25,.5])
+    lb.append(ab,[.25,.5,.25])
+    lb.append(ab,[.5,0,0])
+    lb.append(ab,[.75,.25,0])
+    lb.append(ab,[.75,0,.25])
+    lb.append(ab,[.25,.75,0])
+    lb.append(ab,[.25,0,.75])
+    lb.append(ab,[0,.5,0])
+    lb.append(ab,[0,.75,.25])
+    lb.append(ab,[0,.25,.75])
+    lb.append(ab,[0,0,.5])
+    #O
+    lb.append(ac,[x,x,x])
+    lb.append(ac,[1-x,x+0.25,x+0.25])
+    lb.append(ac,[1-x+0.25,1-x+0.25,x])
+    lb.append(ac,[x+0.25,1-x,x+0.25])
+    lb.append(ac,[x,1-x+0.25,1-x+0.25])
+    lb.append(ac,[x+0.25,x+0.25,1-x])
+    lb.append(ac,[1-x+0.25,x,1-x+0.25])
+    lb.append(ac,[1-x,1-x,1-x])
+    lb.append(ac,[x,.75-x,.75-x])
+    lb.append(ac,[x-.25,x-.25,1-x])
+    lb.append(ac,[.75-x,x,.75-x])
+    lb.append(ac,[1-x,x-.25,x-.25])
+    lb.append(ac,[.75-x,.75-x,x])
+    lb.append(ac,[x-.25,1-x,x-.25])
+    lb.append(ac,[x,.5+x,.5+x])
+    lb.append(ac,[1-x+.25,.25+x,.5+x])
+    lb.append(ac,[.25+x,.5-x,x-.25])
+    lb.append(ac,[x+.25,x-.25,.5-x])
+    lb.append(ac,[1-x+.25,.5+x,1-.25-x])
+    lb.append(ac,[1-x,.5-x,.5-x])
+    lb.append(ac,[x-.25,.25+x,.5-x])
+    lb.append(ac,[.75-x,.5+x,1-x+.25])
+    lb.append(ac,[.75-x,1-x+.25,.5+x])
+    lb.append(ac,[x-.25,.5-x,.25+x])
+    lb.append(ac,[.5+x,x,.5+x])
+    lb.append(ac,[.5-x,.25+x,x-.25])
+    lb.append(ac,[.5+x,1-x+.25,.75-x])
+    lb.append(ac,[.5-x,1-x,.5-x])
+    lb.append(ac,[.5+x,.75-x,1-x+.25])
+    lb.append(ac,[.5-x,x-.25,x+.25])
+    lb.append(ac,[.5+x,.5+x,x])
+    lb.append(ac,[.5-x,.5-x,1-x])
+ 
+    a1=[ a , 0 , 0 ]
+    a2=[ 0 , a , 0 ]
+    a3=[ 0 , 0 , a ]
+    l = Lattice(a1,a2,a3,base=lb)
+    return l
\ No newline at end of file
